@@ -4,8 +4,9 @@ struct MyApp;
 
 impl AppState for MyApp {
     fn on_start(&mut self, s: &mut PixState) -> PixResult<()> {
-        s.background(220)?;
+        s.background(220);
         s.no_cursor();
+        s.stroke(Color::BLACK);
         Ok(())
     }
 
@@ -17,11 +18,7 @@ impl AppState for MyApp {
             s.fill(255);
         }
         let m = s.mouse_pos();
-        s.triangle([
-            point![m.x(), m.y()],
-            point![m.x() + 100, m.y()],
-            point![m.x() + 30, m.y() - 100],
-        ])?;
+        s.circle([m.x(), m.y(), 45])?;
         Ok(())
     }
 
@@ -35,8 +32,7 @@ fn main() -> PixResult<()> {
     let mut engine = PixEngine::builder()
         .with_dimensions(800, 600)
         .with_title("MyApp")
-        .position_centered()
-        .build();
+        .build()?;
     let mut app = MyApp;
     engine.run(&mut app)
 }
