@@ -15,7 +15,7 @@ use std::{
     slice,
 };
 
-/// Format for interpreting bytes when using textures.
+/// Format for interpreting image data.
 #[derive(Debug, Copy, Clone, PartialEq, Eq, Hash)]
 #[non_exhaustive]
 #[must_use]
@@ -44,9 +44,9 @@ impl PixelFormat {
 #[doc(hidden)]
 pub struct TryFromColorTypeError(pub(crate) ());
 
+#[doc(hidden)]
 impl TryFrom<png::ColorType> for PixelFormat {
     type Error = TryFromColorTypeError;
-    #[doc(hidden)]
     fn try_from(color_type: png::ColorType) -> Result<Self, Self::Error> {
         match color_type {
             png::ColorType::Rgb => Ok(Self::Rgb),
@@ -56,8 +56,8 @@ impl TryFrom<png::ColorType> for PixelFormat {
     }
 }
 
+#[doc(hidden)]
 impl From<PixelFormat> for png::ColorType {
-    #[doc(hidden)]
     fn from(format: PixelFormat) -> Self {
         match format {
             PixelFormat::Rgb => Self::Rgb,
@@ -206,8 +206,7 @@ impl Image {
         let png_file = BufReader::new(read);
         let png = Decoder::new(png_file);
 
-        // TODO: Make this machine-dependent to best match display capabilities for texture
-        // performance
+        // TODO: Make this machine-dependent to best match display capabilities for performance
         // EXPL: Switch RGBA32 (RGBA8888) format to ARGB8888 by swapping alpha
         // EXPL: Expand paletted to RGB and non-8-bit grayscale to 8-bits
         // png.set_transformations(Transformations::SWAP_ALPHA | Transformations::EXPAND);
@@ -320,6 +319,8 @@ impl Image {
     /// This consumes the `Image`, so we do not need to copy its contents.
     #[inline]
     #[must_use]
+    // FIXME: https://github.com/rust-lang/rust-clippy/issues/4979
+    #[allow(clippy::missing_const_for_fn)]
     pub fn into_bytes(self) -> Vec<u8> {
         self.data
     }
@@ -509,11 +510,11 @@ impl PixState {
     {
         let s = &self.settings;
         let mut dst = dst.into();
-        if let ImageMode::Center = s.image_mode {
+        if s.image_mode == ImageMode::Center {
             dst = dst.map(|dst| Rect::from_center(dst.top_left(), dst.width(), dst.height()));
         };
         let mut angle = angle.into().unwrap_or(0.0);
-        if let AngleMode::Radians = s.angle_mode {
+        if s.angle_mode == AngleMode::Radians {
             angle = angle.to_degrees();
         };
         self.renderer.image(
