@@ -31,12 +31,14 @@ lazy_static! {
         sdl2::image::init(InitFlag::PNG | InitFlag::JPG).expect("sdl2_image initialized");
 }
 
+pub(crate) use audio::RendererAudioDevice;
+
 mod audio;
 mod event;
 mod texture;
 mod window;
 
-/// An SDL [Renderer] implementation.
+/// A SDL [Renderer] implementation.
 pub(crate) struct Renderer {
     context: Sdl,
     event_pump: EventPump,
@@ -196,13 +198,13 @@ impl Rendering for Renderer {
         windows.insert(primary_window.id, primary_window);
 
         // Set up Audio
-        let audio_sub = context.audio().map_err(PixError::Renderer)?;
+        let audio_subsys = context.audio().map_err(PixError::Renderer)?;
         let desired_spec = AudioSpecDesired {
             freq: Some(s.audio_sample_rate),
             channels: Some(1),
             samples: None,
         };
-        let audio_device = audio_sub
+        let audio_device = audio_subsys
             .open_queue(None, &desired_spec)
             .map_err(PixError::Renderer)?;
         debug!("Loaded AudioDevice: {:?}", audio_device.spec());
@@ -263,7 +265,7 @@ impl Rendering for Renderer {
     #[inline]
     fn clip(&mut self, rect: Option<Rect<i32>>) -> PixResult<()> {
         self.update_canvas(|canvas: &mut Canvas<_>| -> PixResult<()> {
-            canvas.set_clip_rect(rect.map(|rect| rect.into()));
+            canvas.set_clip_rect(rect.map(Into::into));
             Ok(())
         })
     }
@@ -361,7 +363,7 @@ impl Rendering for Renderer {
                 let dst = Some(SdlRect::new(pos.x(), pos.y(), width, height));
                 let result = if angle.is_some() || center.is_some() || flipped.is_some() {
                     let angle = angle.unwrap_or(0.0);
-                    let center = center.map(|c| c.into());
+                    let center = center.map(Into::into);
                     let horizontal = matches!(flipped, Some(Flipped::Horizontal | Flipped::Both));
                     let vertical = matches!(flipped, Some(Flipped::Vertical | Flipped::Both));
                     canvas.copy_ex(texture, src, dst, angle, center, horizontal, vertical)
@@ -469,22 +471,47 @@ impl Rendering for Renderer {
 
     /// Draw a line to the current canvas.
     #[inline]
-    fn line(&mut self, line: LineI2, width: u8, color: Color) -> PixResult<()> {
+    fn line(&mut self, line: LineI2, smooth: bool, width: u8, color: Color) -> PixResult<()> {
         self.update_canvas(|canvas: &mut Canvas<_>| -> PixResult<()> {
             let [x1, y1] = line.start().map(|v| v as i16);
             let [x2, y2] = line.end().map(|v| v as i16);
-            let result = if width == 1 {
+            if width == 1 {
                 if y1 == y2 {
                     canvas.hline(x1, x2, y1, color)
                 } else if x1 == x2 {
                     canvas.vline(x1, y1, y2, color)
-                } else {
+                } else if smooth {
                     canvas.aa_line(x1, y1, x2, y2, color)
+                } else {
+                    canvas.line(x1, y1, x2, y2, color)
                 }
             } else {
                 canvas.thick_line(x1, y1, x2, y2, width, color)
-            };
-            Ok(result.map_err(PixError::Renderer)?)
+            }
+            .map_err(PixError::Renderer)?;
+            Ok(())
+        })
+    }
+
+    /// Draw a cubic Bezier curve to the current canvas.
+    #[inline]
+    fn bezier<I>(&mut self, ps: I, detail: i32, stroke: Option<Color>) -> PixResult<()>
+    where
+        I: Iterator<Item = PointI2>,
+    {
+        self.update_canvas(|canvas: &mut Canvas<_>| -> PixResult<()> {
+            let (vx, vy): (Vec<i16>, Vec<i16>) = ps
+                .map(|p| -> (i16, i16) {
+                    let [x, y] = p.map(|v| v as i16);
+                    (x, y)
+                })
+                .unzip();
+            if let Some(stroke) = stroke {
+                canvas
+                    .bezier(&vx, &vy, detail, stroke)
+                    .map_err(PixError::Renderer)?;
+            }
+            Ok(())
         })
     }
 
@@ -493,6 +520,7 @@ impl Rendering for Renderer {
     fn triangle(
         &mut self,
         tri: TriI2,
+        smooth: bool,
         fill: Option<Color>,
         stroke: Option<Color>,
     ) -> PixResult<()> {
@@ -506,9 +534,12 @@ impl Rendering for Renderer {
                     .map_err(PixError::Renderer)?;
             }
             if let Some(stroke) = stroke {
-                canvas
-                    .trigon(x1, y1, x2, y2, x3, y3, stroke)
-                    .map_err(PixError::Renderer)?;
+                if smooth {
+                    canvas.aa_trigon(x1, y1, x2, y2, x3, y3, stroke)
+                } else {
+                    canvas.trigon(x1, y1, x2, y2, x3, y3, stroke)
+                }
+                .map_err(PixError::Renderer)?;
             }
             Ok(())
         })
@@ -525,30 +556,28 @@ impl Rendering for Renderer {
     ) -> PixResult<()> {
         self.update_canvas(|canvas: &mut Canvas<_>| -> PixResult<()> {
             let [x, y, width, height] = rect.map(|v| v as i16);
-            if let Some(radius) = radius {
-                let radius = radius as i16;
-                if let Some(fill) = fill {
-                    canvas
-                        .rounded_box(x, y, x + width, y + height, radius, fill)
-                        .map_err(PixError::Renderer)?;
-                }
-                if let Some(stroke) = stroke {
-                    canvas
-                        .rounded_rectangle(x, y, x + width, y + height, radius, stroke)
-                        .map_err(PixError::Renderer)?;
-                }
-            } else {
-                // EXPL: SDL2_gfx renders this 1px bigger than it should.
-                if let Some(fill) = fill {
-                    canvas
-                        .box_(x, y, x + width - 1, y + height - 1, fill)
-                        .map_err(PixError::Renderer)?;
-                }
-                if let Some(stroke) = stroke {
-                    canvas
-                        .rectangle(x, y, x + width, y + height, stroke)
-                        .map_err(PixError::Renderer)?;
-                }
+            if let Some(fill) = fill {
+                radius
+                    .map_or_else(
+                        // EXPL: SDL2_gfx renders this 1px bigger than it should.
+                        || canvas.box_(x, y, x + width - 1, y + height - 1, fill),
+                        |radius| {
+                            let radius = radius as i16;
+                            canvas.rounded_box(x, y, x + width, y + height, radius, fill)
+                        },
+                    )
+                    .map_err(PixError::Renderer)?;
+            }
+            if let Some(stroke) = stroke {
+                radius
+                    .map_or_else(
+                        || canvas.rectangle(x, y, x + width, y + height, stroke),
+                        |radius| {
+                            let radius = radius as i16;
+                            canvas.rounded_rectangle(x, y, x + width, y + height, radius, stroke)
+                        },
+                    )
+                    .map_err(PixError::Renderer)?;
             }
             Ok(())
         })
@@ -556,7 +585,13 @@ impl Rendering for Renderer {
 
     /// Draw a quadrilateral to the current canvas.
     #[inline]
-    fn quad(&mut self, quad: QuadI2, fill: Option<Color>, stroke: Option<Color>) -> PixResult<()> {
+    fn quad(
+        &mut self,
+        quad: QuadI2,
+        smooth: bool,
+        fill: Option<Color>,
+        stroke: Option<Color>,
+    ) -> PixResult<()> {
         self.update_canvas(|canvas: &mut Canvas<_>| -> PixResult<()> {
             let [x1, y1] = quad.p1().map(|v| v as i16);
             let [x2, y2] = quad.p2().map(|v| v as i16);
@@ -570,9 +605,12 @@ impl Rendering for Renderer {
                     .map_err(PixError::Renderer)?;
             }
             if let Some(stroke) = stroke {
-                canvas
-                    .polygon(&vx, &vy, stroke)
-                    .map_err(PixError::Renderer)?;
+                if smooth {
+                    canvas.aa_polygon(&vx, &vy, stroke)
+                } else {
+                    canvas.polygon(&vx, &vy, stroke)
+                }
+                .map_err(PixError::Renderer)?;
             }
             Ok(())
         })
@@ -580,7 +618,13 @@ impl Rendering for Renderer {
 
     /// Draw a polygon to the current canvas.
     #[inline]
-    fn polygon<I>(&mut self, ps: I, fill: Option<Color>, stroke: Option<Color>) -> PixResult<()>
+    fn polygon<I>(
+        &mut self,
+        ps: I,
+        smooth: bool,
+        fill: Option<Color>,
+        stroke: Option<Color>,
+    ) -> PixResult<()>
     where
         I: Iterator<Item = PointI2>,
     {
@@ -597,9 +641,12 @@ impl Rendering for Renderer {
                     .map_err(PixError::Renderer)?;
             }
             if let Some(stroke) = stroke {
-                canvas
-                    .polygon(&vx, &vy, stroke)
-                    .map_err(PixError::Renderer)?;
+                if smooth {
+                    canvas.aa_polygon(&vx, &vy, stroke)
+                } else {
+                    canvas.polygon(&vx, &vy, stroke)
+                }
+                .map_err(PixError::Renderer)?;
             }
             Ok(())
         })
@@ -610,6 +657,7 @@ impl Rendering for Renderer {
     fn ellipse(
         &mut self,
         ellipse: Ellipse<i32>,
+        smooth: bool,
         fill: Option<Color>,
         stroke: Option<Color>,
     ) -> PixResult<()> {
@@ -618,14 +666,26 @@ impl Rendering for Renderer {
             let rw = width / 2;
             let rh = height / 2;
             if let Some(fill) = fill {
-                canvas
-                    .filled_ellipse(x, y, rw, rh, fill)
-                    .map_err(PixError::Renderer)?;
+                if width == height {
+                    canvas.filled_circle(x, y, rw, fill)
+                } else {
+                    canvas.filled_ellipse(x, y, rw, rh, fill)
+                }
+                .map_err(PixError::Renderer)?;
             }
             if let Some(stroke) = stroke {
-                canvas
-                    .aa_ellipse(x, y, rw, rh, stroke)
-                    .map_err(PixError::Renderer)?;
+                if width == height {
+                    if smooth {
+                        canvas.aa_circle(x, y, rw, stroke)
+                    } else {
+                        canvas.circle(x, y, rw, stroke)
+                    }
+                } else if smooth {
+                    canvas.aa_ellipse(x, y, rw, rh, stroke)
+                } else {
+                    canvas.ellipse(x, y, rw, rh, stroke)
+                }
+                .map_err(PixError::Renderer)?;
             }
             Ok(())
         })
@@ -704,17 +764,18 @@ impl Rendering for Renderer {
             .context("failed to update image texture")?;
 
         let update = |canvas: &mut Canvas<_>| -> PixResult<()> {
-            let src = src.map(|r| r.into());
-            let dst = dst.map(|r| r.into());
-            let result = if angle > 0.0 || center.is_some() || flipped.is_some() {
-                let center = center.map(|c| c.into());
+            let src = src.map(Into::into);
+            let dst = dst.map(Into::into);
+            if angle > 0.0 || center.is_some() || flipped.is_some() {
+                let center = center.map(Into::into);
                 let horizontal = matches!(flipped, Some(Flipped::Horizontal | Flipped::Both));
                 let vertical = matches!(flipped, Some(Flipped::Vertical | Flipped::Both));
                 canvas.copy_ex(texture, src, dst, angle, center, horizontal, vertical)
             } else {
                 canvas.copy(texture, src, dst)
-            };
-            Ok(result.map_err(PixError::Renderer)?)
+            }
+            .map_err(PixError::Renderer)?;
+            Ok(())
         };
 
         if let Some(texture_id) = self.texture_target {
@@ -825,35 +886,35 @@ impl fmt::Debug for Renderer {
  * Type Conversions
  */
 
+#[doc(hidden)]
 impl ToColor for Color {
     /// Convert [Color] to tuple of `(r, g, b, a)`.
-    #[doc(hidden)]
     fn as_rgba(&self) -> (u8, u8, u8, u8) {
         let [r, g, b, a] = self.channels();
         (r, g, b, a)
     }
 }
 
+#[doc(hidden)]
 impl From<Color> for SdlColor {
     /// Convert [Color] to [`SdlColor`].
-    #[doc(hidden)]
     fn from(color: Color) -> Self {
         let [r, g, b, a] = color.channels();
         Self::RGBA(r, g, b, a)
     }
 }
 
+#[doc(hidden)]
 impl From<FontStyle> for SdlFontStyle {
-    /// Convert [FontStyle] to [`SdlFontStyle`].
-    #[doc(hidden)]
+    /// Convert [`FontStyle`] to [`SdlFontStyle`].
     fn from(style: FontStyle) -> Self {
         Self::from_bits(style.bits()).expect("valid FontStyle")
     }
 }
 
+#[doc(hidden)]
 impl From<Rect<i32>> for SdlRect {
     /// Convert [`Rect<i32>`] to [`SdlRect`].
-    #[doc(hidden)]
     fn from(rect: Rect<i32>) -> Self {
         Self::new(
             rect.x(),
@@ -864,9 +925,9 @@ impl From<Rect<i32>> for SdlRect {
     }
 }
 
+#[doc(hidden)]
 impl From<SdlRect> for Rect<i32> {
     /// Convert [`Rect<i32>`] to [`SdlRect`].
-    #[doc(hidden)]
     fn from(rect: SdlRect) -> Self {
         Self::new(
             rect.x(),
@@ -877,9 +938,9 @@ impl From<SdlRect> for Rect<i32> {
     }
 }
 
+#[doc(hidden)]
 impl From<&Rect<i32>> for SdlRect {
     /// Convert &[`Rect<i32>`] to [`SdlRect`].
-    #[doc(hidden)]
     fn from(rect: &Rect<i32>) -> Self {
         Self::new(
             rect.x(),
@@ -890,25 +951,25 @@ impl From<&Rect<i32>> for SdlRect {
     }
 }
 
+#[doc(hidden)]
 impl From<PointI2> for SdlPoint {
     /// Convert [`PointI2`] to [`SdlPoint`].
-    #[doc(hidden)]
     fn from(p: PointI2) -> Self {
         Self::new(p.x(), p.y())
     }
 }
 
+#[doc(hidden)]
 impl From<&PointI2> for SdlPoint {
     /// Convert &[`PointI2`] to [`SdlPoint`].
-    #[doc(hidden)]
     fn from(p: &PointI2) -> Self {
         Self::new(p.x(), p.y())
     }
 }
 
+#[doc(hidden)]
 impl From<BlendMode> for SdlBlendMode {
     /// Convert [`BlendMode`] to [`SdlBlendMode`].
-    #[doc(hidden)]
     fn from(mode: BlendMode) -> Self {
         match mode {
             BlendMode::None => Self::None,
@@ -919,9 +980,9 @@ impl From<BlendMode> for SdlBlendMode {
     }
 }
 
+#[doc(hidden)]
 impl From<PixelFormat> for SdlPixelFormat {
     /// Convert [`PixelFormat`] to [`SdlPixelFormat`].
-    #[doc(hidden)]
     fn from(format: PixelFormat) -> Self {
         match format {
             PixelFormat::Rgb => Self::RGB24,
