@@ -8,8 +8,8 @@ use sdl2::{
     mouse::MouseButton as SdlMouseButton,
 };
 
+#[doc(hidden)]
 impl From<SdlEvent> for Event {
-    #[doc(hidden)]
     fn from(event: SdlEvent) -> Self {
         match event {
             SdlEvent::Quit { .. } => Self::Quit,
@@ -28,7 +28,7 @@ impl From<SdlEvent> for Event {
                 repeat,
                 ..
             } => Self::KeyDown {
-                key: keycode.map(|k| k.into()),
+                key: keycode.map(Into::into),
                 keymod: keymod.into(),
                 repeat,
             },
@@ -38,7 +38,7 @@ impl From<SdlEvent> for Event {
                 repeat,
                 ..
             } => Self::KeyUp {
-                key: keycode.map(|k| k.into()),
+                key: keycode.map(Into::into),
                 keymod: keymod.into(),
                 repeat,
             },
@@ -205,17 +205,16 @@ impl From<SdlEvent> for Event {
     }
 }
 
+#[doc(hidden)]
 impl From<SdlWindowEvent> for WindowEvent {
-    #[doc(hidden)]
     fn from(win_event: SdlWindowEvent) -> Self {
         match win_event {
             SdlWindowEvent::Shown => Self::Shown,
             SdlWindowEvent::Exposed => Self::Exposed,
             SdlWindowEvent::Hidden => Self::Hidden,
             SdlWindowEvent::Moved(x, y) => Self::Moved(x, y),
-            SdlWindowEvent::Resized(w, h) | SdlWindowEvent::SizeChanged(w, h) => {
-                Self::Resized(w, h)
-            }
+            SdlWindowEvent::Resized(w, h) => Self::Resized(w, h),
+            SdlWindowEvent::SizeChanged(w, h) => Self::SizeChanged(w, h),
             SdlWindowEvent::Minimized => Self::Minimized,
             SdlWindowEvent::Maximized => Self::Maximized,
             SdlWindowEvent::Restored => Self::Restored,
@@ -232,8 +231,8 @@ impl From<SdlWindowEvent> for WindowEvent {
     }
 }
 
+#[doc(hidden)]
 impl From<SdlKeycode> for Key {
-    #[doc(hidden)]
     fn from(keycode: SdlKeycode) -> Self {
         match keycode {
             SdlKeycode::Backspace => Self::Backspace,
@@ -366,8 +365,8 @@ impl From<SdlKeycode> for Key {
     }
 }
 
+#[doc(hidden)]
 impl From<SdlMod> for KeyMod {
-    #[doc(hidden)]
     fn from(keymod: SdlMod) -> Self {
         let mut result = Self::NONE;
         if keymod.contains(SdlMod::LSHIFTMOD) || keymod.contains(SdlMod::RSHIFTMOD) {
@@ -386,8 +385,8 @@ impl From<SdlMod> for KeyMod {
     }
 }
 
+#[doc(hidden)]
 impl From<SdlMouseButton> for Mouse {
-    #[doc(hidden)]
     fn from(button: SdlMouseButton) -> Self {
         match button {
             SdlMouseButton::Left => Self::Left,
@@ -401,8 +400,8 @@ impl From<SdlMouseButton> for Mouse {
     }
 }
 
+#[doc(hidden)]
 impl From<SdlButton> for ControllerButton {
-    #[doc(hidden)]
     fn from(button: SdlButton) -> Self {
         match button {
             SdlButton::A => Self::A,
@@ -430,8 +429,8 @@ impl From<SdlButton> for ControllerButton {
     }
 }
 
+#[doc(hidden)]
 impl From<SdlAxis> for Axis {
-    #[doc(hidden)]
     fn from(axis: SdlAxis) -> Self {
         match axis {
             SdlAxis::LeftX => Self::LeftX,
@@ -444,8 +443,8 @@ impl From<SdlAxis> for Axis {
     }
 }
 
+#[doc(hidden)]
 impl From<SdlHatState> for HatState {
-    #[doc(hidden)]
     fn from(hat: SdlHatState) -> Self {
         match hat {
             SdlHatState::LeftUp => Self::LeftUp,
