@@ -205,8 +205,8 @@ impl WindowCanvas {
     }
 }
 
+#[doc(hidden)]
 impl fmt::Debug for WindowCanvas {
-    #[doc(hidden)]
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         let canvas = &self.canvas;
         f.debug_struct("WindowCanvas")
@@ -289,7 +289,7 @@ impl WindowRenderer for Renderer {
     /// Returns a single event or None if the event pump is empty.
     #[inline]
     fn poll_event(&mut self) -> Option<Event> {
-        self.event_pump.poll_event().map(|evt| evt.into())
+        self.event_pump.poll_event().map(Into::into)
     }
 
     /// Get the current window title.
@@ -372,7 +372,7 @@ impl WindowRenderer for Renderer {
     /// Set the rendering viewport of the current render target.
     #[inline]
     fn set_viewport(&mut self, rect: Option<Rect<i32>>) -> PixResult<()> {
-        self.canvas_mut()?.set_viewport(rect.map(|r| r.into()));
+        self.canvas_mut()?.set_viewport(rect.map(Into::into));
         Ok(())
     }
 
@@ -489,10 +489,8 @@ impl WindowRenderer for Renderer {
     }
 }
 
-impl Renderer {}
-
+#[doc(hidden)]
 impl From<SystemCursor> for SdlSystemCursor {
-    #[doc(hidden)]
     fn from(cursor: SystemCursor) -> Self {
         match cursor {
             SystemCursor::Arrow => Self::Arrow,
