@@ -152,11 +152,49 @@ impl PixState {
     {
         let s = &self.settings;
         if let Some(stroke) = s.stroke {
-            self.renderer.line(line.into(), s.stroke_weight, stroke)?;
+            self.renderer
+                .line(line.into(), s.smooth, s.stroke_weight, stroke)?;
         }
         Ok(())
     }
 
+    /// Draw a cubic Bezier curve to the current canvas. [`PixState::stroke`] controls whether the
+    /// line is drawn or not. [`PixState::bezier_detail`] controls the resolution of the
+    /// curve. [`PixState::fill`] has no effect.
+    ///
+    /// The first and last points are the anchor points of the curve, while the middle points are
+    /// the control points that "pull" the curve towards them.
+    ///
+    /// # Errors
+    ///
+    /// If the renderer fails to draw to the current render target, then an error is returned.
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// # use pix_engine::prelude::*;
+    /// # struct App;
+    /// # impl AppState for App {
+    /// fn on_update(&mut self, s: &mut PixState) -> PixResult<()> {
+    ///     s.stroke(Color::RED);
+    ///     s.bezier([[85, 20], [10, 10], [90, 90], [15, 80]])?;
+    ///     Ok(())
+    /// }
+    /// # }
+    /// ```
+    pub fn bezier<P, I>(&mut self, points: I) -> PixResult<()>
+    where
+        P: Into<PointI2>,
+        I: IntoIterator<Item = P>,
+    {
+        let s = &self.settings;
+        self.renderer.bezier(
+            points.into_iter().map(Into::into),
+            s.bezier_detail,
+            s.stroke,
+        )
+    }
+
     /// Draw a [Triangle][Tri] to the current canvas. [`PixState::fill`] and [`PixState::stroke`]
     /// control whether the triangle is filled or outlined.
     ///
@@ -183,7 +221,8 @@ impl PixState {
         T: Into<TriI2>,
     {
         let s = &self.settings;
-        self.renderer.triangle(tri.into(), s.fill, s.stroke)
+        self.renderer
+            .triangle(tri.into(), s.smooth, s.fill, s.stroke)
     }
 
     /// Draw a square [Rect] to the current canvas. [`PixState::fill`] and [`PixState::stroke`] control
@@ -339,7 +378,7 @@ impl PixState {
         Q: Into<QuadI2>,
     {
         let s = &self.settings;
-        self.renderer.quad(quad.into(), s.fill, s.stroke)
+        self.renderer.quad(quad.into(), s.smooth, s.fill, s.stroke)
     }
 
     /// Draw a polygon to the current canvas. [`PixState::fill`] and [`PixState::stroke`] control
@@ -369,8 +408,12 @@ impl PixState {
         I: IntoIterator<Item = P>,
     {
         let s = &self.settings;
-        self.renderer
-            .polygon(points.into_iter().map(Into::into), s.fill, s.stroke)
+        self.renderer.polygon(
+            points.into_iter().map(Into::into),
+            s.smooth,
+            s.fill,
+            s.stroke,
+        )
     }
 
     /// Draw a wireframe to the current canvas, translated to a given [Point] and optionally
@@ -419,7 +462,7 @@ impl PixState {
         let s = &self.settings;
         let pos = pos.into();
         let mut angle = angle.into().unwrap_or(0.0);
-        if let AngleMode::Degrees = s.angle_mode {
+        if s.angle_mode == AngleMode::Degrees {
             angle = angle.to_radians();
         };
         let scale = scale.into().unwrap_or(1.0);
@@ -495,7 +538,7 @@ impl PixState {
     {
         let s = &self.settings;
         let ellipse = self.get_ellipse(ellipse);
-        self.renderer.ellipse(ellipse, s.fill, s.stroke)
+        self.renderer.ellipse(ellipse, s.smooth, s.fill, s.stroke)
     }
 
     /// Draw an arc of a given `radius` and length defined by `start` and `end` to the current
